# Table of Contents

- [application-rationalization-create-roadmap](<./application-rationalization-create-roadmap.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 5: Create a Rationalization Roadmap](<./Step-5-Create-a-Rationalization-Roadmap.md>)
  - [Prepare Initiatives for Your Roadmap](<./Step-5-Create-a-Rationalization-Roadmap/Prepare-Initiatives-for-Your-Roadmap.md>)
  - [View the Roadmap](<./Step-5-Create-a-Rationalization-Roadmap/View-the-Roadmap.md>)
